yakumo.cmd.ossh

Package yakumo :: Package cmd :: Module ossh |
[hide private]
[frames] | no frames]

# Module ossh

source code

Functions | [hide private]
main() | source code

Variables | [hide private]
| ENVIRONMENT_VARIABLES = ``{``'``os_auth_type``'``:` `'``OS_AUTH_TYPE``'``,` `'``os_c``...``
| __package__ = ``'``yakumo.cmd``'``

Variables Details | [hide private]

  ### ENVIRONMENT_VARIABLES Value:
      {'os_auth_type': 'OS_AUTH_TYPE',
       'os_cacert': 'OS_CACERT',
       'os_cert': 'OS_CERT',
       'os_cloud': 'OS_CLOUD',
       'os_interface': 'OS_INTERFACE',
       'os_key': 'OS_KEY',
       'os_region_name': 'OS_REGION_NAME'}